.. _ref-who-uses:

Sites Using Haystack
====================

The following sites are a partial list of people using Haystack. I'm always
interested in adding more sites, so please find me (``daniellindsley``) via
IRC or the mailing list thread.


LJWorld/Lawrence.com/KUSports
-----------------------------

For all things search-related.

Using: Solr

* http://www2.ljworld.com/search/
* http://www2.ljworld.com/search/vertical/news.story/
* http://www2.ljworld.com/marketplace/
* http://www.lawrence.com/search/
* http://www.kusports.com/search/


AltWeeklies
-----------

Providing an API to story aggregation.

Using: Whoosh

* http://www.northcoastjournal.com/altweeklies/documentation/


Teachoo
-----------

Teachoo uses Haystack for its site search.

Using: Elasticsearch

* https://www.teachoo.com/


Trapeze
-------

Various projects.

Using: Xapian

* http://www.trapeze.com/
* http://www.windmobile.ca/
* http://www.bonefishgrill.com/
* http://www.canadiantire.ca/ (Portions of)


Vickerey.com
------------

For (really well done) search & faceting.

Using: Solr

* http://store.vickerey.com/products/search/


Eldarion
--------

Various projects.

Using: Solr

* http://eldarion.com/


Sunlight Labs
-------------

For general search.

Using: Whoosh & Solr

* http://sunlightlabs.com/
* http://subsidyscope.com/


NASA
----

For general search.

Using: Solr

* An internal site called SMD Spacebook 1.1.
* http://science.nasa.gov/


AllForLocal
-----------

For general search.

* http://www.allforlocal.com/


HUGE
----

Various projects.

Using: Solr

* http://hugeinc.com/
* http://houselogic.com/


Brick Design
------------

For search on Explore.

Using: Solr

* http://bricksf.com/
* http://explore.org/


Winding Road
------------

For general search.

Using: Solr

* http://www.windingroad.com/


Reddit
------

For Reddit Gifts.

Using: Whoosh

* http://redditgifts.com/


Pegasus News
------------

For general search.

Using: Xapian

* http://www.pegasusnews.com/


Rampframe
---------

For general search.

Using: Xapian

* http://www.rampframe.com/


Forkinit
--------

For general search, model-specific search and suggestions via MLT.

Using: Solr

* http://forkinit.com/


Structured Abstraction
----------------------

For general search.

Using: Xapian

* http://www.structuredabstraction.com/
* http://www.delivergood.org/


CustomMade
----------

For general search.

Using: Solr

* http://www.custommade.com/


University of the Andes, Dept. of Political Science
---------------------------------------------------

For general search & section-specific search. Developed by Monoku.

Using: Solr

* http://www.congresovisible.org/
* http://www.monoku.com/


Christchurch Art Gallery
------------------------

For general search & section-specific search.

Using: Solr

* http://christchurchartgallery.org.nz/search/
* http://christchurchartgallery.org.nz/collection/browse/


DevCheatSheet.com
-----------------

For general search.

Using: Xapian

* http://devcheatsheet.com/


TodasLasRecetas
---------------

For search, faceting & More Like This.

Using: Solr

* http://www.todaslasrecetas.es/receta/s/?q=langostinos
* http://www.todaslasrecetas.es/receta/9526/brochetas-de-langostinos


AstroBin
--------

For general search.

Using: Solr

* http://www.astrobin.com/


European Paper Company
----------------------

For general search.

Using: ???

* http://europeanpaper.com/


mtn-op
------

For general search.

Using: ???

* http://mountain-op.com/


Crate
-----

Crate is a PyPI mirror/replacement. It's using Haystack to power all search &
faceted navigation on the site.

Using: Elasticsearch

* https://crate.io/


Pix Populi
----------

Pix Populi is a popular French photo sharing site.

Using: Solr

* http://www.pix-populi.fr/


LocalWiki
----------

LocalWiki is a tool for collaborating in local, geographic communities.
It's using Haystack to power search on every LocalWiki instance.

Using: Solr

* http://localwiki.org/


Pitchup
-------

For faceting, geo and autocomplete.

Using: ???

* http://www.pitchup.com/search/


Gidsy
-----

Gidsy makes it easy for anyone to organize and find exciting things
to do everywhere in the world.

For activity search, area pages, forums and private messages.

Using: Elasticsearch

* https://gidsy.com/
* https://gidsy.com/search/
* https://gidsy.com/forum/


GroundCity
----------

Groundcity is a Romanian dynamic real estate site.

For real estate, forums and comments.

Using: Whoosh

* http://groundcity.ro/cautare/


Docket Alarm
------------

Docket Alarm allows people to search court dockets across
the country. With it, you can search court dockets in the International Trade
Commission (ITC), the Patent Trial and Appeal Board (PTAB) and All Federal
Courts.

Using: Elasticsearch

* https://www.docketalarm.com/search/ITC
* https://www.docketalarm.com/search/PTAB
* https://www.docketalarm.com/search/dockets


Educreations
-------------

Educreations makes it easy for anyone to teach what they know and learn
what they don't with a recordable whiteboard. Haystack is used to
provide search across users and lessons.

Using: Solr

* http://www.educreations.com/browse/
